@@ -138,6 +138,12 @@ class Strong_Adapter<T> : public Strong_Base<T> {
          this->get().resize(size);
       }
 
+      void reserve(size_type size) noexcept(noexcept(this->get().reserve(size)))
+         requires(concepts::reservable_container<T>)
+      {
+         this->get().reserve(size);
+      }
+
       decltype(auto) operator[](size_type i) const noexcept(noexcept(this->get().operator[](i))) {
          return this->get()[i];
       }
@@ -163,19 +169,37 @@ class Strong : public detail::Strong_Adapter<T> {
    public:
       using detail::Strong_Adapter<T>::Strong_Adapter;
 
+      template <typename CapabilityT>
+      constexpr static bool has_capability() {
+         return (std::is_same_v<CapabilityT, Capabilities> || ...);
+      }
+
    private:
       using Tag = TagTypeT;
 };
 
+/**
+ * Opportunistically unpacks a strong type to its underlying type. If the
+ * provided type is not a strong type, it is returned as is.
+ */
+template <typename T>
+constexpr decltype(auto) unpack(T& t) {
+   if constexpr(concepts::strong_type<std::remove_cvref_t<T>>) {
+      return t.get();
+   } else {
+      return t;
+   }
+}
+
 template <typename T, typename... Tags>
-   requires(concepts::streamable<T>) decltype(auto)
-operator<<(std::ostream& os, const Strong<T, Tags...>& v) {
+   requires(concepts::streamable<T>)
+decltype(auto) operator<<(std::ostream& os, const Strong<T, Tags...>& v) {
    return os << v.get();
 }
 
 template <typename T, typename... Tags>
-   requires(std::equality_comparable<T>) bool
-operator==(const Strong<T, Tags...>& lhs, const Strong<T, Tags...>& rhs) {
+   requires(std::equality_comparable<T>)
+bool operator==(const Strong<T, Tags...>& lhs, const Strong<T, Tags...>& rhs) {
    return lhs.get() == rhs.get();
 }
 
@@ -584,6 +608,15 @@ class StrongSpan {
       underlying_span m_span;
 };
 
+template <typename>
+struct is_strong_span : std::false_type {};
+
+template <typename T>
+struct is_strong_span<StrongSpan<T>> : std::true_type {};
+
+template <typename T>
+constexpr bool is_strong_span_v = is_strong_span<T>::value;
+
 }  // namespace Botan
 
 #endif
